@@ -16,7 +16,7 @@ if os.environ.get('READTHEDOCS', None) == 'True':
 extensions = ['sphinx.ext.todo', 'sphinx.ext.viewcode', 'breathe']
 
 theme_major = sphinx_rtd_theme.__version__.partition('.')[0]
-if theme_major == '2':
+if theme_major >= '2':
     extensions.append('sphinxcontrib.jquery')
 
 # Breathe configuration
